@@ -57,6 +57,16 @@ def main():
                 commands['module'](target, name)
             return
 
+        if '.' in name:
+            manager, _, command = name.partition('.')
+            manager = getattr(target, manager)
+            command = getattr(manager, command)
+            gen = command(*args)
+            if gen:
+                for vals in gen:
+                    print('\t'.join(vals))
+            return
+
         if name=='help':
             cmd = help
             help(args[0] if args else None)
